==> applitutoriel-js-lite-5.3.0.tgz: package/src/services/data/ref/ref-pays-service-impl.ts <==
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */

/**
 * applitutoriel-js-lite - Application tutoriel utilisant le Framework hornet
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.3.0
 * @link git+https://github.com/diplomatiegouvfr/applitutoriel-modules.git
 * @license CECILL-2.1
 */

import { Utils } from "hornet-js-utils";
import { Logger } from "hornet-js-utils/src/logger";
import { BusinessError } from "hornet-js-utils/src/exception/business-error";
import { PaysDAO } from "src/dao/pays-dao";
import { VilleDAO } from "src/dao/ville-dao";
import { ReferentielPaysService } from "applitutoriel-js-common/src/services/page/ref/ref-pays-service";
import { PaysMetier } from "applitutoriel-js-common/src/models/ref/ref-pay-mod";
import { VilleMetier } from "applitutoriel-js-common/src/models/ref/ref-ville-mod";
import { ModelDAO } from "src/dao/model-dao";
import { HornetSequelizeInstanceModel } from "hornet-js-database/src/sequelize/hornet-sequelize-attributes";
import { VilleAttributes } from "src/models/ref/ref-ville-mod";
import { PaysAttributes } from "src/models/ref/ref-pay-mod";
import { BeanUtils } from "hornet-js-bean/src/bean-utils";

const logger: Logger = Utils.getLogger("applitutoriel.src.services.ref.ref-pays-service-impl");

export class ReferentielPaysServiceImpl extends ReferentielPaysService {
    private paysDAO: PaysDAO = new PaysDAO();
    private villeDAO: VilleDAO = new VilleDAO();

    listerPays(): Promise<PaysMetier[]> {
        logger.trace("SERVICES - listerPays");
        return this.paysDAO.findAllGeneric<PaysMetier>(null, PaysMetier)
            .catch(function (err) {
            throw new BusinessError(err);
        });
    }

    rechercherNationalites(nationalite: string): Promise<PaysMetier[]> {
        logger.trace("SERVICES - rechercherNationalites : ", nationalite);
        if (!nationalite) {
            nationalite = "";
        }
        return this.paysDAO.selectNationaliteLike(nationalite).catch(function (err) {
            throw new BusinessError(err);
        });
    }

    listerVilles(): Promise<VilleMetier[]> {
        logger.trace("SERVICES - listerVilles");
        return this.villeDAO.listerVilles().catch(function (err) {
            throw new BusinessError(err);
        });
    }

    chercherPays(id): Promise<PaysMetier> {
        logger.trace("SERVICES - chercherPays, id :", id);
        return this.paysDAO.findByIdGeneric<PaysMetier>(id, PaysMetier)
            .catch(function (err) {
                throw new BusinessError(err);
            });
    }

    chercherVille(id): Promise<VilleMetier> {
        logger.trace("SERVICES - chercherVille, id :", id);
        return this.villeDAO.findByIdGeneric<VilleMetier>(id, VilleMetier)
            .catch(function (err) {
                throw new BusinessError(err);
            });
    }
}

==> applitutoriel-js-lite-5.4.1.tgz: package/src/services/data/ref/ref-pays-service-impl.ts <==
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */

/**
 * applitutoriel-js-lite - Application tutoriel utilisant le Framework hornet
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.4.1
 * @link git+https://github.com/diplomatiegouvfr/applitutoriel-modules.git
 * @license CECILL-2.1
 */

import { Logger } from "hornet-js-logger/src/logger";
import { BusinessError } from "hornet-js-utils/src/exception/business-error";
import { PaysDAO }  from "applitutoriel-js-lite/src/dao/pays-dao";
import { VilleDAO }  from "applitutoriel-js-lite/src/dao/ville-dao";
import { ReferentielPaysService } from "applitutoriel-js-common/src/services/page/ref/ref-pays-service";
import { PaysMetier } from "applitutoriel-js-common/src/models/ref/ref-pay-mod";
import { VilleMetier } from "applitutoriel-js-common/src/models/ref/ref-ville-mod";
import { Promise } from "hornet-js-utils/src/promise-api";

const logger: Logger = Logger.getLogger("applitutoriel.src.services.ref.ref-pays-service-impl");

export class ReferentielPaysServiceImpl extends ReferentielPaysService {
    private paysDAO: PaysDAO = new PaysDAO();
    private villeDAO: VilleDAO = new VilleDAO();

    listerPays(): Promise<PaysMetier[]> {
        logger.trace("SERVICES - listerPays");
        return this.paysDAO.findAllGeneric<PaysMetier>(null, PaysMetier)
            .catch(function (err) {
            throw new BusinessError(err);
        });
    }

    rechercherNationalites(nationalite: string): Promise<PaysMetier[]> {
        logger.trace("SERVICES - rechercherNationalites : ", nationalite);
        if (!nationalite) {
            nationalite = "";
        }
        return this.paysDAO.selectNationaliteLike(nationalite).catch(function (err) {
            throw new BusinessError(err);
        });
    }

    listerVilles(): Promise<VilleMetier[]> {
        logger.trace("SERVICES - listerVilles");
        return this.villeDAO.listerVilles().catch(function (err) {
            throw new BusinessError(err);
        });
    }

    chercherPays(id): Promise<PaysMetier> {
        logger.trace("SERVICES - chercherPays, id :", id);
        return this.paysDAO.findByIdGeneric<PaysMetier>(id, PaysMetier)
            .catch(function (err) {
                throw new BusinessError(err);
            });
    }

    chercherVille(id): Promise<VilleMetier> {
        logger.trace("SERVICES - chercherVille, id :", id);
        return this.villeDAO.findByIdGeneric<VilleMetier>(id, VilleMetier)
            .catch(function (err) {
                throw new BusinessError(err);
            });
    }
}
